from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\xdf\x98\x33\xfa\x3e\x72\x6e\xfc\xa3\xad\xfa\x2c\x09\xdc\x9f\x6c\x00\x00\x00\x00\x00\x00\x00\x00\x9f\x08\xf7\x7b\x0a\xf7\x02\x30\x88\x8b\x33\xfa\x57\x6b\x74\xb0\xec\x76\x34\xda\xb5\xce\x59\x67\x30\x63\x3a\x72\xe8\x9e\xe7\x6f\xd4\xb2\x86\x81\x0b\x62\x69\x03\x9c\x75\xe3\x1a\x69\x04\xdf\xf2\xf1\x7a\x52\xc9\x43\x7e\xf1\xc0\x0b\x04\xa4\xaf\x54\xef\x35\x9a\x71\x9c\x76\x62\x87\xb2\x10\x43\x66\xb6\x2c\x83\xcf\xd4\x01\x8c\xa5\x5d\xab\x3f\xba\xd1\x96\x7c\xd3\xa9\xbd\x5b\x58\x63\xe2\x4e\xb8\xf4\x41\x41\x7c\x4d\xb5\xb0\xdb\xd1\x78\x51\xb5\xd8\x20\x60\x53\x2e\x3f\x98\x54\x90\x2e\xe4\x65\x49\xbe\x47\x93\xc9\x49\x6c\x19\xa0\x4b\x78\x93\x3d\x47\x94\xd3\x84\x7b\x15\x0e\x07\x15\x5b\x21\x62\x45\xa1\x8e\x05\xf5\x00\x0e\xf3\x65\x68\x55\xfa\x75\x88\x02\x09\x5c\x50\xee\x10\x00\x32\x8e\xf8\x10\x18\xd9\x2a\xde\x3c\xc2\x68\xc1\x90\x0e\x6d\xbb\xd8\xac\x9f\x4d\x40\x22\xe6\xd0\x7c\xc8\xbc\xea\x1d\x10\xcd\xc2\xf3\x55\xf3\xec\x35\x96\x38\x86\xfd\x64\xbe\xa4\x95\x59\xa6\x91\xc2\x2c\x78\x05\xca\xdc\xf6\x2b\x61\x42\x56\x58\xa7\x26\x6b\x35\x1f\xf8\x0c\x40\xec\xec\x33\x48\x66\x7a\xa6\x77\x2d\x7d\x2c\x0f\xa7\x4f\xf1\xe4\x29\x09\x31\x98\xed\x28\xb0\xdb\x8e\x84\xb5\x50\xcf\x86\x3d\x5b\x36\xf2\xea\x50\x03\xe4\x65\xfd\xc6\x57\xac\xed\x4f\x8e\x03\x3b\xf0\x35\x98\xca\x3d\xdf\x75\xa5\xcd\x69\xcb\xbf\x7c\x72\xf5\x52\xe3\xfc\x22\x4c\xf7\x52\x1e\xf1\x6f\x09\x73\x12\x31\x9d\x05\x56\xbf\x42\xe5\x32\x4c\xa2\x7e\x8e\x78\x2f\x14\x27\x73\x97\x30\x3f\xe3\x92\x52\xaa\x82\xdf\xd8\xb0\x59\xf7\x30\xaa\xc3\x89\x63\xed\xff\x83\xe2\xd0\xec\x8f\xf7\x1d\x21\x1b\x43\x5f\xcf\x49\x5c\x7e\x55\x37\xe8\x93\xab\x1f\x27\x64\x1e\x63\x2c\x32\xc5\x82\x5d\x7f\xd3\xe4\x11\x5b\x10\x41\x44\x1b\x05\x5d\xbc\x06\x67\x4a\x14\x41\x43\x1e\x38\x33\xe9\x4b\xe7\x1f\x9d\x45\xbf\xa2\xb3\xce\xa5\xf7\xc6\xb0\xfd\xa5\x59\xb6\x6e\x20\xba\x00\x2c\xdb\x77\x25\x43\x98\xbd\x35\xac\xcd\xc6\xe8\xad\xdd\xb9\x24\x04\x49\x93\x03\x05\x4b\xab\x0e\x40\x06\x86\xfc\x07\xa9\xb0\x1b\xbc\xfc\x60\x25\xde\xef\x7c\x59\x24\xc6\xe9\x2e\xa8\x47\x1c\x0e\x28\x9a\x4e\x71\xaf\xe6\xc3\x47\x64\x88\x19\x1f\x2f\x06\xd1\x46\xa8\xdf\x52\x1b\x49\xaa\xf4\xa8\xa9\xb5\x69\x3d\xce\x2a\x87\x82\x82\xe3\xf7\x86\xd0\xe9\x64\x90\x5d\xc7\xea\x22\x76\xab\x34\xe3\x3f\xed\xcd\xa4\x1e\x78\xf8\x5b\xc3\xae\x1f\xb7\xab\xe4\x28\x6c\x1a\xf1\xd1\xe4\x0a\xdb\x4d\xef\x0d\x02\xd1\xaf\x8c\x5f\xf2\xda\x9b\xb3\x9f\xdb\x2e\xe4\x49\x4a\xad\x1f\x9a\x6e\x4d\x9b\x9d\x5e\x13\xd4\x4d\xb4\x6b\x15\xcc\x4e\x7e\x57\x47\xe0\xca\x7d\x78\x5e\x6f\x7f\x89\x34\x96\x9b\x2c\x90\xc6\x48\x98\x48\xcb\x10\x23\x6d\x6e\x95\x6c\x59\x55\x66\x27\xef\xe6\xe2\x69\x5e\xbc\xc5\xfe\x04\x58\x82\xfa\x14\xc4\xa0\xa4\xc6\xb5\x3c\x24\x8a\x88\x26\xe9\xc8\x4b\xbd\x21\x20\xd7\xd1\xa1\x39\x9f\x12\xe0\xfc\xc0\x54\xd9\xeb\xcd\x10\xfe\xad\x81\x84\x5f\xb1\x58\x5a\xfa\x37\x78\x85\x61\x09\xb2\x92\x5f\x45\xb9\xc2\x4e\x82\xc1\x42\x5e\xdb\xdb\x27\x84\x21\x90\x3a\x7c\xa9\x09\xb7\xee\x19\xee\x3a\x57\xcd\xf1\xf2\x32\xae\x16\xfb\xa9\x8c\x23\x83\x8a\x8a\x11\x01\x96\x28\xc9\x6c\xe8\xca\xb4\x7d\xe2\x6f\x87\xb8\x59\xe7\x95\xa6\xab\x4c\x19\x4e\xf1\x94\x3d\x24\xe9\xd3\x8b\xe2\x16\x25\xab\xf3\xe3\xa9\xc3\xb9\x47\x68\x21\x05\x8a\xc3\xd4\x8f\x6a\xba\x7a\x08\xcc\xa9\x22\xbe\x76\x28\xb4\x62\xb8\x55\x25\x9c\x8f\x2c\xd7\x0b\xa2\x60\x55\x49\x67\x25\x17\x47\x6f\xb2\xfd\xd8\xa6\xc7\x35\xac\xc9\x63\xb8\x2d\xff\x28\xd1\x96\xfc\x13\xc8\xed\x46\xf0\xf5\x6a\x20\x5e\xdb\x20\x93\xd0\x1b\x58\x9e\x93\xdb\x88\xe0\x08\x31\x91\x76\x93\xdf\x30\x60\x53\x8b\x9e\x95\x63\x38\x07\xae\x02\xc1\x72\xa0\x9a\x7f\x38\x5d\xe8\x3a\x4f\x75\xf7\x90\xbc\x72\x2f\x0a\xf3\x3c\x11\x66\xdc\xb8\xec\x84\x29\x7c\xac\xa6\x7f\x07\x41\xb3\x02\x1d\x45\x70\x79\x55\x61\xf2\x4b\xa0\xb2\x82\xf3\xaf\xb6\xfc\x03\x84\xe6\xc1\x1f\xbe\xb6\xff\xbb\xf9\xc8\x34\xe8\xca\x92\xf9\xd7\x31\x43\x78\xe9\x18\x8c\x7f\xa0\x3d\x36\xc9\x96\x9e\x7e\xcf\x36\x58\xc1\x44\xb5\xed\x49\x73\x1f\xa7\x68\xdd\x66\x64\x42\x34\x4c\x2e\x0f\x4b\x23\x2c\x1f\x86\x84\x13\xce\x90\x04\x08\x9f\x6a\x91\x37\x03\xba\xad\x69\xc7\x62\x44\x36\xfa\x80\x1f\x12\xe2\x10\x18\x27\x05\x3d\xb0\xb7\x4e\xae\xbb\xf2\xec\x37\x4a\x47\xb9\x8c\x87\xbe\x8b\x5a\x79\xdb\xf4\xe2\xd0\xcd\xe0\xa7\x58\xd3\xb8\x66\x55\x5e\x5f\xbe\xa8\x2b\xf1\x8f\x6d\x35\xaa\x26\xc6\xf3\x2f\x3c\x3e\xed\xfb\xbc\x02\x07\x78\xda\xd2\x78\x72\xce\x36\x18\x26\x0b\x83\x26\xb4\x93\x66\x8c\x53\xfc\x76\x53\x12\xa5\xf6\x79\x93\xa4\x26\x81\x8c\xf0\xf4\x78\xd0\x16\x74\xef\x37\x3b\xc0\xe6\xfe\xcd\x74\xea\x47\xc2\x4f\x77\x34\x1f\xae\xd5\xeb\x8f\x5d\xdc\x9f\xcc\x01\x69\x3e\x51\xf1\xac\x59\x0d\xeb\xc6\xf1\x14\xd9\x3a\x50\x2c\x02\x60\x36\x31\xf1\xfe\x30\xea\x61\x24\x64\xa2\x76\x91\xd0\x84\x01\x55\x6c\xb4\x4b\xb2\xfa\xdc\x8f\xb2\x6a\x7b\x15\x2e\x12\xa4\x67\xbe\xf2\xaa\x4a\xf7\x45\x41\xd5\x22\xa4\x7e\x0a\x18\xa4\x16\xe0\x67\x66\xb2\xca\x61\x80\x30\x73\x59\x1b\xc7\x7c\xce\x78\x32\xb2\x7c\xdc\x3d\x6e\xc9\x56\xbc\x52\x23\x46\x84\xec\x12\x46\x9b\x7a\xea\xd3\xf5\xa6\xcf\x46\xd2\x3c\xbe\x0a\xf3\xc0\x2d\x5f\xcf\x26\x1c\xd1\x68\xfb\x0b\xc4\xb9\xfd\x41\x8e\xd1\x3c\x65\xf0\x35\x3e\xd2\xcd\x70\x04\x8f\x4d\x0d\xfc\x5d\xfc\x37\xb3\x95\xb1\xb6\x51\x00\xd7\xfb\x5e\x85\xe3\xbc\xa7\x7b\x47\x97\x85\xcb\x13\xbe\x66\x07\x3e\xd8\xec\xd0\xdf\xa5\x91\x7b\xdf\x85\x13\x14\xe2\xf1\xce\xdf\x8e\x80\x59\xaf\x6f\x79\x97\x1f\x39\x60\x65\xbb\x79\xf6\x45\x3f\x71\xfd\x7f\x7a\x41\x6a\x92\x41\x7f\x6e\x0c\x58\x19\x8d\x03\x74\xeb\xcc\xbe\xc7\x8c\x41\xdd\x1b\x12\xa9\xcd\x5b\x71\xa5\x5a\x7a\xbc\x79\x92\x00\xfc\xa3\x99\x7e\x0c\xa4\x73\xa9\xdb\x2a\x42\xd5\xb2\x34\x26\x65\x4a\x6d\x84\xbd\x7a\x54\x44\x8c\xec\xcf\x6b\x10\xd1\xcf\xed\x8d\x41\x5f\x0a\x38\x77\x57\x46\xd7\x58\xf6\x73\x7c\x12\xcd\xbe\xb1\xab\x92\xef\xfd\x00\xee\x43\x65\x1b\xce\xf0\xc1\xbf\x94\x44\x2a\x2b\x5d\x93\x99\x26\x84\xc2\xde\x56\xfb\x5d\x6d\xbd\x93\xe3\xe6\x63\x8e\x63\xdf\xde\xde\xaf\xec\x11\xa2\xc9\x2e\xe2\x19\x4b\x11\x48\x92\xe8\x77\xa0\xfa\x2f\x63\x06\x97\xf1\xba\xca\x2a\x6a\xd7\x6f\x91\xb5\xdb\x3e\x56\x7a\x88\x90\x71\xe6\x70\x2e\x16\x45\x92\x0d\x18\xf3\xc2\x96\x82\xc0\x02\x72\x16\xe7\x9a\x83\xe2\x2b\x38\x0f\x3b\x50\xb2\xa4\x46\x1d\x93\x54\xbd\xfc\x04\x50\x36\x9f\xd7\xb6\x1b\xa9\x5d\x15\x0d\x46\xc9\x0e\x52\xa0\x89\x30\x71\xb8\x80\x49\x49\xd0\x54\x04\x2b\x39\x5a\x0a\xd8\x9c\x29\xdd\xeb\x72\x3a\x65\x62\x7b\x2a\xdb\xa2\x8c\xf5\xbe\xf2\xd8\x51\xcf\xaa\xe6\x04\xa6\xc7\x36\x5f\x72\x9e\xfe\xbc\x8a\xc2\x48\xe1\x39\x74\x89\x4a\xc8\xcf\x05\x14\x27\x8e\xe1\x35\x53\xb9\xd0\x2c\x3e\x55\x1a\x21\x49\xf7\xf5\x91\x70\xba\xa0\x8c\x98\x6c\xfc\x5e\xb7\x1e\x99\x44\x8f\x7f\x51\xc8\x9f\xad\x7c\xce\x7f\x49\xef\xbc\x09\xfd\x1a\xf1\xae\x35\xcf\x4f\xdc\x2d\x7d\xb3\xd2\xd0\x24\x82\xa4\x84\xf2\xd6\x24\x5d\x1c\x35\x1a\x76\x8c\x3c\x5c\x21\x31\xe8\x4c\xfe\xea\x7e\x98\x2f\x86\x15\x4b\x40\x70\xc4\x06\x3d\x49\x4c\x59\x5d\x36\xa7\xcc\x53\x29\xd6\x9b\xc2\x84\x0c\x60\x68\xed\x89\x45\x4a\x07\xb8\x05\x78\xfb\x71\x68\xe6\x4d\x86\x68\xe7\xe4\x0e\x1d\x98\xe9\x0e\x41\x71\x34\xe1\x8c\x20\x45\x19\xe8\xd1\xea\x4a\xd1\xd3\xee\x5a\x38\x17\xdc\x7a\x7a\xfe\xdc\x3a\xfa\xc7\xcc\x57\xae\x8f\xe5\x77\xe7\xfc\x26\xa8\x03\x4e\xf1\x72\x99\xa8\xaa\x88\xfd\x04\x4f\x31\x1e\x98\x30\x39\xae\x91\x2a\x99\x58\xeb\x8a\xc6\xaf\x60\xbf\x32\xc9\x83\x6b\xd5\x60\x86\xd5\x98\x12\x4d\x96\x55\x74\x6c\x84\xcb\xab\x7d\xac\x89\xb8\xd2\xc7\xae\x19\x19\x7f\xce\x86\x88\xa1\xc7\xa6\x17\xac\x44\xbd\xfb\x7a\x38\xf3\x68\xde\xb4\xe6\x6f\xc1\xce\xb6\x33\x50\x1a\x4c\x86\xcd\x35\xec\xf4\x99\xcf\x1f\xfa\xf7\xa1\x04\xde\x6d\xd8\x4e\xa3\x0b\x4a\xfd\x95\x32\x51\xcf\x49\xb6\x4b\xeb\x5f\xbf\xb3\xa8\x2f\xb4\xb2\xb6\x9d\xc7\xd9\xc0\x1a\xec\x07\x6d\x83\x7e\xc8\xbb\x1e\x8e\x5a\xcb\x16\x9b\x8a\xe6\xae\xb8\xb9\x9b\xb4\x78\x57\x67\xe9\x58\x70\x97\xc8\xa3\x95\x75\x43\x81\x6c\x3c\x53\x67\xd1\x33\xa8\xcb\xed\xef\xfd\xa0\xbb\x34\x95\x1a\x88\xef\xad\xa0\x7a\x81\xee\xb7\x1c\xdf\x07\x4d\x38\x28\x6c\x87\x18\x2a\x04\x47\x52\x98\xb9\x67\x6d\xad\x1a\xde\x67\x86\x3e\xb6\xf1\x9f\xd8\xa7\x0e\xbb\x3c\x7b\x25\xcb\x51\x4c\xd7\x87\xf5\xf9\xbb\x39\x03\x9b\xac\x20\xb7\x7d\x99\x54\xa5\xd4\xc2\x73\xda\x70\xd9\xd2\x61\x63\x2d\x7a\x80\x1e\x4c\xd9\x95\xfd\xd9\x0d\xdc\x6b\x53\x6f\x38\x68\x3e\xf2\xea\x4a\xc9\x9a\x5d\x54\x74\x4e\x82\x63\x2e\x67\x91\x08\x85\xa6\x8f\x8e\x0f\xde\x27\x7d\x2c\xb3\x3e\x81\x92\xe2\x98\xfd\xd5\x26\x0b\xf8\xaa\x7e\xaa\xe0\x97\x64\xc8\xf8\x4b\xc1\x6a\xa6\xf3\xc6\xbc\xf6\x05\x03\x97\xf3\x0c\x2f\xa3\xba\xfd\xfc\x56\xa1\x49\xeb\x79\x38\x2b\x8d\x10\x70\x71\xa8\xe2\x79\xb0\x56\x0a\xeb\x06\xd6\xfd\x36\x18\x64\x83\xf5\x83\xae\x22\xb7\x3b\x49\xf1\x33\xdc\x73\x33\xab\xb8\x7f\x86\x9a\x82\xd9\x92\x70\xdb\x75\x71\x6d\x16\xf8\xec\x30\x85\xbb\x1d\x63\xba\x2a\x0f\xa0\xe3\x44\xaa\x20\x83\x62\x64\x01\x58\x38\x9d\xe7\x56\x6b\x36\x58\x97\x0e\x52\x16\x8b\x34\x6b\xfe\x0e\xbc\x59\x6d\x93\xc5\x71\x25\x18\x11\x6b\x36\xb3\xae\xeb\x25\x20\x95\x43\xdd\xac\xcc\xf9\xa1\x3a\x68\x27\xde\x2d\x77\x94\xc8\x39\xac\x91\xef\x76\x52\x41\x8e\x4d\x60\x7f\xec\x4e\x16\x0f\x6a\x3d\xbf\x62\xf3\xe3\x2d\xdc\xd4\x6c\x1a\xe4\x75\x34\x02\x0c\xb0\xa6\x58\xb9\xb2\xd4\xcf\xd2\xa6\x61\x33\xa2\x3e\xe8\xf5\x24\x09\xac\x2b\x12\x12\x28\x63\xf4\x35\x3b\xc2\x13\xa3', 2)

# cleanup
del pyarmor_runtime

